## loading data for the Campbell et al paper on female representation 
rm(list = ls())

library(foreign)

#### BES section: mass attitudes ####


bes = read.spss("bes20012005.sav", to.data.frame = T) ## this is the data Rosie Campbell sent Andy Eggers on September 23 

bes2001 = read.dta("2001BES.dta") # this is the data Andy Eggers had lying around for the 2001 BES 
# how do the two relate?

## 1910 rows for 2001 in "bes"; 3035 in bes2001
## but let's check the responses to the key questions. 

## cq17a-d are the questions about women in bes2001
# they are binary in "bes" but ordinal scale in "bes2001"

# let's see how they agree
table(bes$mennobetter[bes$year == 2001])
table(bes2001$cq17b[!bes2001$cq17b %in% c("no mailback", "not ascertainable")] %in% c("disagree", "strongly disagree")) # that's close -- some extras included in bes2001. perhaps because they gave missing on something else? 

table(bes$husno[bes$year == 2001])
table(bes2001$cq17d[!bes2001$cq17d %in% c("no mailback", "not ascertainable")] %in% c("disagree", "strongly disagree")) # that's close too; again some extras in bes2001

table(bes$womenmore[bes$year == 2001])
table(bes2001$cq17c[!bes2001$cq17c %in% c("no mailback", "not ascertainable")] %in% c("disagree", "strongly disagree", "neither agree nor disagree")) # close but reversed, as noted in the paper

table(bes$womenrep[bes$year == 2001])
table(bes2001$cq17a[!bes2001$cq17a %in% c("no mailback", "not ascertainable")] %in% c("disagree", "strongly disagree", "neither agree nor disagree")) # close but reversed, as noted in the paper

## So my judgment is that Campbell et al converted the BES I have here into binary variables (hostile to traditional women's role or otherwise -- i.e. neutral or favorable are put together), and then did some listwise deletion. 

## The main question for Giacomo is how the factor analysis was done -- when we have that we should be able to do the regressions more or less properly. 

## my first attempt at the factor analysis: 

fa1 = factanal(bes[,c("mennobetter", "husno", "womenmore", "womenrep")], factors = 2) ## -- produces error: 2 factors are too many for 4 variables 

# this does work and gives semi-similar answers 
library(psych)
fa2 = principal(bes[,c("mennobetter", "husno", "womenmore", "womenrep")], nfactors = 2, rotate = "varimax") # principal components analysis 

# let's see how close that looks to figs 2 and 3
bes.agg = aggregate(fa2$scores[,1:2], by = list(bcohort = bes$bcohort, gender = bes$women), FUN = mean, na.rm = T)

bcohorts = sort(unique(bes$bcohort))

par(mfrow = c(1,2))

plot(1:length(bcohorts), 1:length(bcohorts), ylim = range(bes.agg$PC1, na.rm = T), type = "n", xlab = "Birth cohort", ylab = "Hostility to descriptive representation of women", main = "Figure 2?", axes = F)
axis(1, at = 1:length(bcohorts), labels = bcohorts)
axis(2)
lines(1:length(bcohorts), bes.agg[bes.agg$gender == "Men", "PC1"])
lines(1:length(bcohorts), bes.agg[bes.agg$gender == "Women", "PC1"], lty = 2)

plot(1:length(bcohorts), 1:length(bcohorts), ylim = range(bes.agg$PC2, na.rm = T), type = "n", xlab = "Birth cohort", ylab = "Hostility to descriptive representation of women", main = "Figure 3?", axes = F)
axis(1, at = 1:length(bcohorts), labels = bcohorts)
axis(2)
lines(1:length(bcohorts), bes.agg[bes.agg$gender == "Men", "PC2"])
lines(1:length(bcohorts), bes.agg[bes.agg$gender == "Women", "PC2"], lty = 2)

# Both close-ish. 

# Now for some regressions: we don't have the Ron Johnston covariates but we can try the first two models 
bes1 = cbind(bes, fa2$scores)
# need to generate an "age" variable -- generating it from age group. note that if we use the original BES I think we have age -- bq72 in BES2001 and bq77/aq48 in BES2005
bes1$age.group = as.integer(gsub("\\-.+", "", bes1$bcohort, perl = T))
bes1$age = 2005 - bes1$age.group
# and an interaction -- this is really not the correct way to do this but it seems to be what they did 
bes1$intx = (bes1$age.group >= 1945) & (bes1$women == "Women")

# all of these are pretty close 
(t2m1 = summary(lm(PC1 ~ I(women == "Women"), data = bes1[bes1$year == 2005,]))) # table 2 model 1: close-ish
(t2m2 = summary(lm(PC1 ~ I(women == "Women") + age + intx, data = bes1[bes1$year == 2005,]))) # table 2 model 2: also close-ish
(t3m1 = summary(lm(PC2 ~ I(women == "Women"), data = bes1[bes1$year == 2005,]))) # table 3 model 1
(t3m2 = summary(lm(PC2 ~ I(women == "Women") + age + intx, data = bes1[bes1$year == 2005,]))) # table 3 model 2

# note that the number of observations doesn't quite agree, but the number of observations in the tables is kind of suspicious anyway -- why are there more observatiosn in the second model than the first? 





### BRS section: elite attitudes ### 

brs = read.spss("brscombined.sav", to.data.frame = T)  ## this is data that Rosie Campbell sent Andy Eggers on August 26 

# the five questions about gender mentioned in the paper are 
# "equalchance"
# "menpol"
# "womenwork"
# "houseful"
# "husjob" 

# the other two are (I think)
# wsrole 
# equalopp

# here the factors are included in the dataset -- I think they are genroles01 and genroles05

# Figure 4

agg = aggregate(brs[, c("genroles01", "genroles05")], by = list(bcohort = brs$bcohort, gender = brs$women), FUN = mean, na.rm = T)

bcohorts = sort(unique(brs$bcohort))

par(mfrow = c(1,2))
plot(1:length(bcohorts), 1:length(bcohorts), ylim = range(agg[,c("genroles01", "genroles05")], na.rm = T), type = "n", xlab = "Birth cohort", ylab = "Attitudes toward traditional gender roles", main = "2001", axes = F)
axis(1, at = 1:length(bcohorts), labels = bcohorts)
axis(2)
lines(1:length(bcohorts), agg[agg$gender == "Men", "genroles01"])
lines(1:length(bcohorts), agg[agg$gender == "Women", "genroles01"], lty = 2)

plot(1:length(bcohorts), 1:length(bcohorts), ylim = range(agg[,c("genroles01", "genroles05")], na.rm = T), type = "n", xlab = "Birth cohort", ylab = "Attitudes toward traditional gender roles", main = "2005", axes = F)
axis(1, at = 1:length(bcohorts), labels = bcohorts)
axis(2)
lines(1:length(bcohorts), agg[agg$gender == "Men", "genroles05"])
lines(1:length(bcohorts), agg[agg$gender == "Women", "genroles05"], lty = 2)

# not surprisingly that is right on target 

# now for the regressions 
# It's ambiguous how to construct some of these variables -- religious attendance, birth cohort, etc

# how to code up religious attendance? let's try 1-4 etc
brs$my.religattend = NA
brs$my.religattend[brs$religattend == "never"] = 0
brs$my.religattend[brs$religattend == "less than once a year"] = 1
brs$my.religattend[brs$religattend == "at least once a month"] = 2
brs$my.religattend[brs$religattend == "at least once a week"] = 3

# birth cohort -- what can that mean to include it directly in the regression? I will put a number on each cohort, i.e. treat is as a cardinal or interval variable. basically it is a rescaled "first year of birth cohort"
brs$my.bcohort = NA
for(i in 1:length(bcohorts)){
	brs$my.bcohort[brs$bcohort == bcohorts[i]] = i
}

(t4m1 = summary(lm(genroles01 ~ women + con + libdem + my.bcohort + married + my.religattend + degree, data = brs)))

(t4m3 = summary(lm(eqpro ~ women + con + libdem + my.bcohort + married + my.religattend + degree, data = brs[brs$year == 2001,])))

(t4m4 = summary(lm(eqguar ~ women + con + libdem + my.bcohort + married + my.religattend + degree, data = brs[brs$year == 2001,])))

(t4m5 = summary(lm(genroles05 ~ women + con + libdem + my.bcohort + married + my.religattend + degree, data = brs)))

(t4m7 = summary(lm(eqpro ~ women + con + libdem + my.bcohort + married + my.religattend + degree, data = brs[brs$year == 2005,])))

(t4m8 = summary(lm(eqguar ~ women + con + libdem + my.bcohort + married + my.religattend + degree, data = brs[brs$year == 2005,])))

## these are quite close, including number of observations. probably close enough for our purposes. 